#
# spec file for package nomacs
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nomacs
Version:        3.8.1
Release:        lp152.3.13
Summary:        Lightweight image viewer
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Viewers
Url:            https://nomacs.org/
Source:         https://github.com/%{name}/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE nomacs-use-quazip-qt5.patch aloisio@gmx.com -- Link to the Qt5 version of quazip.
Patch0:         nomacs-use-quazip-qt5.patch
BuildRequires:  cmake >= 2.8
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  lcov
BuildRequires:  libqt5-linguist-devel >= 5.2
BuildRequires:  opencv-qt5-devel >= 2.4.6
BuildRequires:  pkgconfig
BuildRequires:  quazip-qt5-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent) >= 5.2
BuildRequires:  pkgconfig(Qt5Network) >= 5.2
BuildRequires:  pkgconfig(Qt5PrintSupport) >= 5.2
BuildRequires:  pkgconfig(Qt5Svg) >= 5.2
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.2
BuildRequires:  pkgconfig(exiv2) >= 0.25
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(libraw) >= 0.17
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(zlib)
Recommends:     %{name}-lang

%description
nomacs is a free image viewer, which is small, fast and able to handle the
most common image formats. Additionally it is possible to synchronise
multiple viewers. A synchronisation of viewers running on the same
computer or via LAN is possible. It allows to compare images and spot the
differences (e.g. schemes of architects to show the progress).

%lang_package

%prep
%setup -q
%patch0 -p1
sed -i 's/\r$//g' ImageLounge/Readme/*

%build
pushd ImageLounge/
%cmake \
  -DCMAKE_BUILD_TYPE=Release                           \
  -DCMAKE_C_FLAGS='%{optflags} -fno-strict-aliasing'   \
  -DCMAKE_CXX_FLAGS='%{optflags} -fno-strict-aliasing' \
  -DUSE_SYSTEM_QUAZIP=ON                               \
  -DCMAKE_SHARED_LINKER_FLAGS=""                       \
  -DENABLE_TRANSLATIONS=ON
make %{?_smp_mflags} V=1
popd

%install
pushd ImageLounge/
%cmake_install
popd
%if 0%{?suse_version} < 1500
mv %{buildroot}%{_datadir}/{metainfo,appdata}/
%endif

rm %{buildroot}%{_libdir}/lib%{name}*.so
%suse_update_desktop_file %{name}
%find_lang %{name} --with-qt
%fdupes %{buildroot}%{_datadir}/

%post
/sbin/ldconfig
%if 0%{?suse_version} < 1500
%desktop_database_post
%endif

%postun
/sbin/ldconfig
%if 0%{?suse_version} < 1500
%desktop_database_postun
%endif

%files
%if 0%{?suse_version} >= 1500
%license ImageLounge/Readme/COPYRIGHT ImageLounge/Readme/LICENSE*
%else
%doc ImageLounge/Readme/COPYRIGHT ImageLounge/Readme/LICENSE*
%endif
%doc ImageLounge/Readme/README
%{_bindir}/%{name}
%{_libdir}/lib%{name}*.so.*
%{_datadir}/%{name}/
%exclude %{_datadir}/%{name}/translations/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.*
%if 0%{?suse_version} >= 1500
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/%{name}.appdata.xml
%else
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%endif
%{_mandir}/man?/%{name}.?%{?ext_man}

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}/translations/

%changelog
* Mon Apr 16 2018 sor.alexei@meowr.ru
- Update to version 3.8.1:
  * Update lipqpsd.
  * Add themes.
  * Add a basic dark theme.
- Use the %%license tag for licences.
* Tue Feb 20 2018 aloisio@gmx.com
- Added nomacs-use-quazip-qt5.patch to link against quazip-qt5
* Sun Nov 26 2017 sor.alexei@meowr.ru
- Build with the Release build type (gh#opencv/opencv#10105).
- Re-enable locales.
* Fri Nov 10 2017 sor.alexei@meowr.ru
- Update to version 3.8.0:
  * Full PhaseOne Support (Monochrome).
  * Optimise RAW loader (less RAM & speed-up).
  * Improve RAW loading (reduce pink pixels).
  * Fix Drag & Drop.
  * Fix batch resize.
  * Fix GPS link.
  * Fix the translation downloader.
- Remove nomacs-remove-datetime.patch.
* Tue Mar 28 2017 sor.alexei@meowr.ru
- Update to version 3.6.1 (changes since 3.4):
  * Introduce image adjustments.
  * Add Exposure.
  * Batch:
    + Improve profiles
    + Add image adjustments.
    + Add settings for batch plugins
  * Extended tab functions.
  * Settings Editor
  * Icons for high DPI displays.
  * Fix a crash on exit.
  * Move bug reporting to GitHub.
- Add nomacs-remove-datetime.patch: Remove __DATE__ and __TIME__.
* Sat Jul 23 2016 sor.alexei@meowr.ru
- Update to version 3.4:
  * Rework Batch UI.
  * Add Batch Profiles.
  * Cropping to metadata.
  * Improve RGB to Gray.
  * Fix crash on delete.
  * Fix slow thumbnail rendering.
  * Improve start-up time.
  * Fix RAW/PSD orientation.
- Remove nomacs-3.2.0-gcc6.patch: fixed upstream.
- Remove /usr/lib(|64)/libnomacs*.so files: for development, yet
  no development seem possible for nomacs now.
- Add ldconfig to post(|un).
* Fri Jun 17 2016 sor.alexei@meowr.ru
- Add nomacs-3.2.0-gcc6.patch from
  https://github.com/nomacs/nomacs/issues/62: fix GCC6 errors
  (boo#985374).
* Wed May  4 2016 sor.alexei@meowr.ru
- Update to version 3.2.0:
  * Redesign plugin framework.
  * New preferences.
  * Add Undo & History dock.
  * Improve statusbar (e.g. zoom level).
  * All Icons are SVG (UHD monitors).
  * Add compression to Batch.
  * Extend image transitions (swipe).
- Remove nomacs-3.0.0-opencv-detection.patch: fixed upstream.
* Fri Mar  4 2016 sor.alexei@meowr.ru
- Add nomacs-3.0.0-opencv-detection.patch to fix detection of
  OpenCV 3.x and later.
* Thu Dec 17 2015 sor.alexei@meowr.ru
- Update to 3.0.0:
  * Add plugins support.
  * Full SVG support.
  * Add Quick Launch.
  * Add Tiny Planet option.
  * Improve batch processing.
  * Add command line arguments.
  * Improve zoom control.
  * Add Bulgarian and Ukrainian translations.
- Remove nomacs-qt5-build-fix.patch.
* Thu Aug 20 2015 sor.alexei@meowr.ru
- Update to 2.4.6:
  * Directory ScrollBar added again (and updated).
  * Fix various crashes (metadata saving/displaying).
  * Fix sorting.
  * Fix some minor bugs.
- Rebase nomacs-qt5-build-fix.patch.
* Fri Apr 17 2015 sor.alexei@meowr.ru
- Update to 2.4.4:
  * Improved batch processing (add images from multiple directories).
  * New Metadata HUD panel (choose entries dynamically).
  * Default strings are now translated.
  * File sorting is (hopefully) fixed.
  * Gamma correction for rescaling is now 16 bit (smooth gradients).
  * Zoom to Fit added (replaces ‘Reset Zoom’).
  * Saving of multiple tabs.
  * UTF-8 encoding for image notes.
  * General stability improvements.
- Rebase nomacs-qt5-build-fix.patch.
* Mon Mar  2 2015 sor.alexei@meowr.ru
- Update to 2.4.2:
  * Image Manipulations are fixed now (black images on e.g. gamma).
  * Resize with gamma correction (black images if gamma was
    checked).
  * Crash fix (if reload occurred after an image resize).
  * Fix Batch Processing.
  * Fix GIF movie toolbar.
  * Update translations.
- Add nomacs-qt5-build-fix.patch.
* Thu Feb 26 2015 sor.alexei@meowr.ru
- Update to 2.4.0:
  * Batch processing (you can try it by clicking
    Tools > Batch Processing).
  * Image tabs (open multiple images within different tabs).
  * Thumbnail preview improved (copy/paste delete/rename is now
    supported).
  * Zoom panel improved (you can now chose a specific zoom level).
  * Olympus RAW added.
  * Convert to grayscale added.
  * Faster directory loading (especially if you have many images
    in a directory).
  * Gesture improvements.
  * Saving of images from archives (e.g. zip, docx) is now supported.
  * File sorting improved.
  * Stability improvements.
- Remove nomacs-strcmp-fix.patch and nomacs-qt5-build-fix.patch.
* Wed Nov 12 2014 sor.alexei@meowr.ru
- Update to 2.2.0:
  * Bugfixes and new features
    (see http://nomacs.org/redmine for details).
- Compile against Qt5 instead of Qt4.
- Rebase nomacs-strcmp-fix.patch.
- Add nomacs-qt5-build-fix.patch.
* Sun Aug  3 2014 sor.alexei@meowr.ru
- Update to 2.0.2.
* Thu Apr 17 2014 sor.alexei@meowr.ru
- Update to 1.6.4.
- Embrace openSUSE packaging policy.
* Sun Feb 24 2013 ti.eugene@gmail.com
- Update to 1.0.
* Thu May 24 2012 petr@scribus.info
- Update to 0.3.2.
* Sat Mar  3 2012 petr@scribus.info
- Update to 0.3.0.
* Mon Dec  5 2011 petr@scribus.info
- Initial package.
